==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/Diki/Article.pm <==
#
# WiKicker
#
#  Article.pm
#
#
# Copyright (C) 2004 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Article.pm,v 1.1 2004/05/30 04:18:30 naney Exp $
#
#

package WiKicker::Diki::Article;

use 5.005;
use strict;
use Carp;
use Log::Log4perl;
use Storable qw(freeze thaw);
use WiKicker::Diki::LinkMaker;

sub new {
  my ($class, %param) = @_;

  if (exists $param{serialized}) {
    my $self = thaw($param{serialized});
    bless $self, $class;
    return $self;
  }

  my $self = bless {}, $class;
  if (exists $param{text}) {
    croak "no id param" unless exists $param{id};
    croak "no last_modified param" unless exists $param{last_modified};
    croak "no term_list param" unless exists $param{term_list};
    croak "no term_list_modified param" unless exists $param{term_list_modified};
    croak "no environment param" unless exists $param{environment};
    $self->{id} = $param{id};
    $self->_id_format_check;
    $self->_initialize_by_text($param{text},
                               $param{last_modified},
                               $param{term_list},
                               $param{term_list_modified},
                               $param{environment});
  }

  return $self;
}

sub id { shift->{id} }
sub text { shift->{text} }
sub last_modified { shift->{last_modified} }
sub term_list_modified { shift->{term_list_modified} }

sub serialize {
  my $self = shift;

  $self->_check_serialize_field;

  my %tmp;
  for my $key (keys %$self) {
    if (substr($key, 0, 13) eq 'no_serialize_') {
      $tmp{$key} = $self->{$key};
      delete $tmp{$key};
    }
  }
  my $serialized = freeze($self);
  Log::Log4perl->get_logger
      ->info(sub { my $id = $self->id;
                   my $length = length($serialized); # byte?
                   return qq("article serialized size: $id: $length bytes");
                 });

  for my $key (keys %tmp) {
    $self->{$key} = $tmp{$key};
  }

  return freeze($self);
}

sub update {
  my ($self, %param) = @_;

  Log::Log4perl->get_logger->info(sub { my $id = $self->id;
                                        my $type = '';
                                        if ($self->last_modified <
                                            $param{last_modified}) {
                                          $type = ' primary changed';
                                        }
                                        elsif ($self->term_list_modified <
                                               $param{term_list_modified}) {
                                          $type = ' term list changed';
                                        }
                                        return qq("article update: $id$type");
                                      }
                                 );

  $self->_initialize_by_text($param{text},
                             $param{last_modified},
                             $param{term_list},
                             $param{term_list_modified},
                             $param{environment});
}

sub _initialize_by_text {
  my ($self, $text, $last_modified,
      $term_list, $term_list_modified, $environment) = @_;

  $self->{text} = $text;
  $self->{last_modified} = $last_modified;
  $self->{term_list_modified} = $term_list_modified;

  $self->{html} = $self->_make_html($text, $term_list, $environment);
}

sub _make_html {
  my ($self, $text, $term_list) = @_;

  croak "You must overload " . __PACKAGE__ . "::_make_html (" . ref($self) . ")";
}

sub set_explicit_term_list {
  my ($self, $list) = @_;
  $self->{no_serialize_explicit_term_list} = $list;
}

sub set_implicit_term_list {
  my ($self, $list) = @_;
  $self->{no_serialize_implicit_term_list} = $list;
}

sub explicit_term_list { shift->{no_serialize_explicit_term_list} }
sub implicit_term_list { shift->{no_serialize_implicit_term_list} }

sub _create_html_env {
  my ($self, $environment, $term_list) = @_;

  eval "use WiKicker::WikiPage::Env";
  croak $@ if $@;
  eval "use WiKicker::PageNameList";
  croak $@ if $@;
  my $env = WiKicker::WikiPage::HtmlEnv->new(environment => $environment,
                                             configuration => $environment->configuration,
                                             localizer => $environment,
                                             wikicker_url => $environment->url,
                                             wri_factory => $environment->create_wri_factory,
                                             page_name_list =>
                                             WiKicker::PageNameList->new($term_list),
                                             resolver => $environment->resolver,
                                             article => $self);


  my $link_maker = WiKicker::Diki::LinkMaker->new_from_html_env(env => $env);
  $env->link_maker($link_maker);
  return $env;
}

sub to_html {
  my $self = shift;

  my $last_modified = WiKicker::Time::gmtime_to_W3CDTF_UTC($self->last_modified);
  my $term_list_modified = WiKicker::Time::gmtime_to_W3CDTF_UTC($self->term_list_modified);
  return '<!-- article id: ' . $self->id . " -->\n"
    . '<!-- last modified: ' . $last_modified . " -->\n"
    . '<!-- keyword list last modified: ' . $term_list_modified . " -->\n"
    . $self->{html};
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/Diki/Article.pm <==
#
# WiKicker
#
#  Article.pm
#
#
# Copyright (C) 2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Article.pm,v 1.5 2005/04/04 14:07:58 naney Exp $
#
#

package WiKicker::Diki::Article;

use 5.005;
use strict;
use Carp;
use Log::Log4perl;
use Storable qw(freeze thaw);
use WiKicker::Diki::LinkMaker;
use WiKicker::UTF8;

sub new {
  my ($class, %param) = @_;

  if (exists $param{serialized}) {
    my $self = thaw($param{serialized});
    bless $self, $class;
    return $self;
  }

  my $self = bless {}, $class;
  if (exists $param{text}) {
    croak 'no id param' unless exists $param{id};
    croak 'no last_modified param' unless exists $param{last_modified};
    croak 'no term_list param' unless exists $param{term_list};
    croak 'no term_list_modified param' unless exists $param{term_list_modified};
    croak 'no environment param' unless exists $param{environment};
    $self->{id} = $param{id};
    $self->_id_format_check;
    $self->_initialize_by_text($param{text},
                               $param{last_modified},
                               $param{term_list},
                               $param{term_list_modified},
                               $param{environment});
  }

  return $self;
}

sub id { shift->{id} }
sub text { shift->{text} }
sub last_modified { shift->{last_modified} }
sub term_list_modified { shift->{term_list_modified} }
sub html { shift->{html} }

sub serialize {
  my $self = shift;

  $self->_check_serialize_field;

  my %tmp;
  for my $key (keys %$self) {
    if (substr($key, 0, 13) eq 'no_serialize_') {
      $tmp{$key} = $self->{$key};
      delete $tmp{$key};
    }
  }
  my $serialized = freeze($self);
  Log::Log4perl->get_logger
      ->info(sub { my $id = $self->id;
                   my $length = length($serialized); # byte?
                   return qq("article serialized size: $id: $length bytes");
                 });

  for my $key (keys %tmp) {
    $self->{$key} = $tmp{$key};
  }

  return freeze($self);
}

sub update {
  my ($self, %param) = @_;

  Log::Log4perl->get_logger->info(sub { my $id = $self->id;
                                        my $type = '';
                                        if ($self->last_modified <
                                            $param{last_modified}) {
                                          $type = ' primary changed';
                                        }
                                        elsif ($self->term_list_modified <
                                               $param{term_list_modified}) {
                                          $type = ' term list changed';
                                        }
                                        return qq("article update: $id$type");
                                      }
                                 );

  $self->_initialize_by_text($param{text},
                             $param{last_modified},
                             $param{term_list},
                             $param{term_list_modified},
                             $param{environment});
}

sub _initialize_by_text {
  my ($self, $text, $last_modified,
      $term_list, $term_list_modified, $environment) = @_;

  $self->{text} = $text;
  $self->{last_modified} = $last_modified;
  $self->{term_list_modified} = $term_list_modified;

  $self->{html} = $self->_make_html($text, $term_list, $environment);
}

sub _make_html {
  my ($self, $text, $term_list) = @_;

  croak 'You must overload ' . __PACKAGE__ . '::_make_html (' . ref($self) . ')';
}

sub set_explicit_term_list {
  my ($self, $list) = @_;
  $self->{no_serialize_explicit_term_list} = $list;
}

sub set_implicit_term_list {
  my ($self, $list) = @_;
  $self->{no_serialize_implicit_term_list} = $list;
}

sub explicit_term_list { shift->{no_serialize_explicit_term_list} }
sub implicit_term_list { shift->{no_serialize_implicit_term_list} }

sub _create_html_env {
  my ($self, $environment, $term_list) = @_;

  eval "use WiKicker::WikiPage::Env";
  croak $@ if $@;
  eval "use WiKicker::PageNameList";
  croak $@ if $@;
  my $env = WiKicker::WikiPage::HtmlEnv->new(environment => $environment,
                                             localizer => $environment,
                                             wikicker_url => $environment->url,
                                             wri_factory => $environment->create_wri_factory,
                                             page_name_list =>
                                             WiKicker::PageNameList->new($term_list),
                                             resolver => $environment->resolver,
                                             article => $self);


  my $link_maker = WiKicker::Diki::LinkMaker->new_from_html_env(env => $env);
  $env->link_maker($link_maker);
  return $env;
}

sub to_html {
  my $self = shift;

  my $last_modified = WiKicker::Time::gmtime_to_W3CDTF_UTC($self->last_modified);
  my $term_list_modified = WiKicker::Time::gmtime_to_W3CDTF_UTC($self->term_list_modified);
  return '<!-- article id: ' . $self->id . " -->\n"
    . '<!-- last modified: ' . $last_modified . " -->\n"
    . '<!-- keyword list last modified: ' . $term_list_modified . " -->\n"
    . $self->html;
}

sub text_from_html {
  my $self = shift;

  my $text = $self->html;
  $text =~ s/<.*?>//g;

  return WiKicker::UTF8::shorten($text, 300);
}

1;
